@@ -15,4 +15,4 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Tests for sieve units for tensorflow."""
+"""Tests for step units for tensorflow."""
