@@ -75,6 +75,10 @@ class PipelineUnitError(AdviserPipelineException):
     """An exception raised when there is an error during pipeline run, unexpectedly."""
 
 
+class PipelineUnitConfigurationSchemaError(PipelineUnitError):
+    """An exception raised when pipeline unit configuration does not match schema declared."""
+
+
 class BootError(PipelineUnitError):
     """An exception raised when pipeline boot unit fails unexpectedly."""
 
@@ -117,12 +121,13 @@ class AdviserRunException(AdviserException):
 class UnresolvedDependencies(AdviserRunException):
     """An exception raised if dependencies were not resolved and cannot produce stack."""
 
-    __slots__ = ["unresolved"]
+    __slots__ = ["unresolved", "stack_info"]
 
-    def __init__(self, *args: Any, unresolved: List[str]) -> None:
+    def __init__(self, *args: Any, unresolved: List[str], stack_info: List[Dict[str, Any]]) -> None:
         """Capture unresolved dependencies in this exception."""
         super().__init__(*args)
         self.unresolved = unresolved
+        self.stack_info = stack_info
 
     def to_dict(self) -> Optional[Dict[str, Any]]:
         """Convert unresolved dependencies exception to the user."""
@@ -132,15 +137,26 @@ class UnresolvedDependencies(AdviserRunException):
             "dependencies were not yet solved in Thoth "
             "cannot resolve all direct dependencies",
             "_ERROR_DETAILS": {"unresolved": self.unresolved,},
+            "stack_info": self.stack_info,
         }
 
 
 class CannotProduceStack(AdviserRunException):
     """Raised if there was not produced any result."""
 
-    def to_dict(self) -> Optional[Dict[str, str]]:
+    __slots__ = ["stack_info"]
+
+    def __init__(self, *args: Any, stack_info: List[Dict[str, Any]]) -> None:
+        """Instantiate the exception."""
+        super().__init__(*args)
+        self.stack_info: List[Dict[str, Any]] = stack_info
+
+    def to_dict(self) -> Optional[Dict[str, Any]]:
         """Convert exception to a dict representation for a user."""
-        return {"ERROR": "No results were resolved, see logs for more info"}
+        return {
+            "ERROR": "No results were resolved, see logs for more info",
+            "stack_info": self.stack_info,
+        }
 
 
 class UserLockFileError(AdviserRunException):
