@@ -48,8 +48,7 @@ class TensorFlow21Urllib3Step(Step):
 
     _message_logged = attr.ib(type=bool, default=False, init=False)
 
-    # Run this step each time, regardless of when TensorFlow and urllib3 are resolved.
-    MULTI_PACKAGE_RESOLUTIONS = True
+    CONFIGURATION_DEFAULT = {"package_name": "urllib3", "multi_package_resolution": False}
 
     _MESSAGE = (
         "TensorFlow in version 2.1 can cause runtime errors when imported, caused by "
@@ -61,6 +60,7 @@ class TensorFlow21Urllib3Step(Step):
     def pre_run(self) -> None:
         """Initialize this pipeline unit before each run."""
         self._message_logged = False
+        super().pre_run()
 
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
@@ -80,10 +80,7 @@ class TensorFlow21Urllib3Step(Step):
         self, state: State, package_version: PackageVersion
     ) -> Optional[Tuple[Optional[float], Optional[List[Dict[str, str]]]]]:
         """Suggest not to use TensorFlow 2.1 with specific urllib3 as issues with six were spotted on imports."""
-        if (
-            package_version.name != "urllib3"
-            or package_version.semantic_version.release[:2] not in self._AFFECTED_URLLIB3_VERSIONS
-        ):
+        if package_version.semantic_version.release[:2] not in self._AFFECTED_URLLIB3_VERSIONS:
             return None
 
         tensorflow_any = (
