@@ -49,18 +49,13 @@ class TensorFlow22ProbabilityStep(Step):
     https://github.com/tensorflow/tensorflow/issues/40584
     """
 
-    # Run this step each time, regardless of when tensorflow and tensorflow-probability are resolved.
-    MULTI_PACKAGE_RESOLUTIONS = True
+    CONFIGURATION_DEFAULT = {"package_name": "tensorflow-probability", "multi_package_resolution": False}
 
     _MESSAGE = "TensorFlow in version 2.2 and tensorflow-probability cause runtime errors"
     _LINK = jl("tf_40584")
 
     _message_logged = attr.ib(type=bool, default=False, init=False)
 
-    def pre_run(self) -> None:
-        """Initialize this pipeline unit before each run."""
-        self._message_logged = False
-
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
         """Register this pipeline unit for adviser if not using latest recommendations."""
@@ -75,13 +70,15 @@ class TensorFlow22ProbabilityStep(Step):
 
         return None
 
+    def pre_run(self) -> None:
+        """Initialize this pipeline unit before each run."""
+        self._message_logged = False
+        super().pre_run()
+
     def run(
         self, state: State, package_version: PackageVersion
     ) -> Optional[Tuple[Optional[float], Optional[List[Dict[str, str]]]]]:
         """Suggest not to use TensorFlow 2.2 with with tensorflow-probability."""
-        if package_version.name != "tensorflow-probability":
-            return None
-
         tensorflow_any = (
             state.resolved_dependencies.get("tensorflow")
             or state.resolved_dependencies.get("tensorflow-cpu")
